@@ -17,7 +17,7 @@
 */
 
 /*
- * FSView specialisaton of TreeMap classes.
+ * FSView specialization of TreeMap classes.
  */
 
 #ifndef FSVIEW_H
@@ -27,7 +27,6 @@
 #include <qfileinfo.h>
 #include <qstring.h>
 
-#include <kmimetype.h>
 #include <kconfiggroup.h>
 
 #include "treemap.h"
@@ -71,8 +70,8 @@ class FSView : public TreeMapWidget, public ScanListener
 public:
     enum ColorMode { None = 0, Depth, Name, Owner, Group, Mime };
 
-    explicit FSView(Inode *, QWidget *parent = Q_NULLPTR);
-    ~FSView();
+    explicit FSView(Inode *, QWidget *parent = nullptr);
+    ~FSView() override;
 
     KConfig *config()
     {
@@ -102,7 +101,7 @@ public:
 
     /* Implementation of listener interface of ScanManager.
      * Used to calculate progress info */
-    void scanFinished(ScanDir *) Q_DECL_OVERRIDE;
+    void scanFinished(ScanDir *) override;
 
     void stop();
 
@@ -130,7 +129,7 @@ signals:
     void completed(int dirs);
 
 protected:
-    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *) override;
 
 private:
     KConfig *_config;
