@@ -20,6 +20,7 @@
 #ifndef SETTINGS_PLUGIN
 #define SETTINGS_PLUGIN
 
+#include <kparts_version.h>
 #include <kparts/plugin.h>
 
 class KConfig;
@@ -29,6 +30,9 @@ class SettingsPlugin : public KParts::Plugin
     Q_OBJECT
 public:
     SettingsPlugin(QObject *parent,
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+                   const KPluginMetaData& metaData,
+#endif
                    const QVariantList &);
     ~SettingsPlugin() override;
 
