@@ -88,7 +88,7 @@ SearchBarPlugin::SearchBarPlugin(QObject *parent,
 
     QAction *a = actionCollection()->addAction(QStringLiteral("focus_search_bar"));
     a->setText(i18n("Focus Searchbar"));
-    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_S));
+    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_S));
     connect(a, &QAction::triggered, this, &SearchBarPlugin::focusSearchbar);
     m_searchProvidersDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/kde5/services/searchproviders/";
     QDir().mkpath(m_searchProvidersDir);
@@ -221,7 +221,7 @@ void SearchBarPlugin::startSearch(const QString &search)
     if (m_searchMode == FindInThisPage) {
         KParts::TextExtension *textExt = KParts::TextExtension::childObject(m_part);
         if (textExt) {
-            textExt->findText(search, nullptr);
+            textExt->findText(search, KFind::SearchOptions());
         }
     } else if (m_searchMode == UseSearchProvider) {
         m_urlEnterLock = true;
